pub enum EclipseKind {
Solar,
Lunar,
}Expand description
Whether an eclipse is of the Sun (Moon between Earth and Sun, at new moon) or of the Moon (Earth between Sun and Moon, at full moon).
Variants
Solar
Solar eclipse: the Moon occults the Sun at a new moon near a node.
Lunar
Lunar eclipse: the Moon passes through Earth’s shadow at a full moon near a node.